using System;
using System.Collections.Generic;

using SteCore;

using ScriptReturn = System.Collections.Generic.IEnumerable<SteCore.ScriptCondition.Base>;
using SteCore.ScriptCondition;

namespace Script
{
	public static class TestLevel
	{
		public static ScriptReturn OnEnter(Level obj, ScriptEventArgs args)
		{
			obj.ScriptVars.SetValue("stage", 0);
			SoundManager.BudgetPad bgMusic = SoundManager.Current.PushMusic(
				ContentProvider.Current.RequestSound("Sfx\\Attack"),
				SoundManager.BudgetPriority.Action);
			bgMusic.Sound.Looped = true;
			
			Camera.Current.FadeIn(0.5f);
			
			ScriptManager.Current.RunScript(obj, args, UpdateAttackWaves);
			yield return null;
		}
		public static ScriptReturn OnLeave(Level obj, ScriptEventArgs args)
		{
			SoundManager.Current.PopMusicHigh();
			yield return null;
		}
		public static ScriptReturn OnCheckFinished(Level obj, LevelFinishStateEventArgs args)
		{
			if (Player.Current.ControlObject == null)
				args.State = LevelFinishState.Failed;
			else
				args.State = LevelFinishState.NotYet;
			yield return null;
		}
		
		
		public static ScriptReturn UpdateAttackWaves(Level obj, ScriptEventArgs args)
		{
			while (Level.Current == obj)
			{
				bool foundBadGuys = false;
				Fraction badGuys = BlueprintManager.Current.FindBlueprint<Fraction>("Fraction_Ugnat");
				foreach (Ship s in ShipManager.Current.Ships)
				{
					if (s.Fraction == badGuys)
					{
						foundBadGuys = true;
						break;
					}
				}
				if (Player.Current.ControlObject != null){
					((Ship)(Player.Current.ControlObject)).ShieldHP+=0.01f*10.0f;
					if (((Ship)(Player.Current.ControlObject)).ShieldHP>1.0f){
						((Ship)(Player.Current.ControlObject)).ShieldHP=1.0f;
					}
				}
				
				if (!foundBadGuys &&
					Player.Current.ControlObject != null)
				{
					int stage;
					obj.ScriptVars.GetValue("stage", out stage);
					stage++;
					obj.ScriptVars.SetValue("stage", stage);
					ItemDesc equipLaser = new ItemDesc();
					ItemDesc equipLaser2 = new ItemDesc();
					equipLaser.blueprint = "ItemBP_HumanLaserLight";
					equipLaser2.blueprint = "ItemBP_UgnatLaserLight";
				int extraShips=0;
				foreach (Ship s in ShipManager.Current.Ships)
				{
					if (s.Fraction != badGuys)
					{
						extraShips+=1;
					}
				}
					for (int i = 0; i < stage+extraShips-1; i++)
					{
						Ship newShip = Ship.Create(
							"ShipBP_UgnatFighter", 
							badGuys.Id,
							Player.Current.ControlObject.Pos.x + SteApp.Current.Rnd.Next(-1500, 1500)-5000.0f, 
							Player.Current.ControlObject.Pos.y + SteApp.Current.Rnd.Next(-1500, 1500)-5000.0f);
						newShip.AICapabilities = AICaps.Fight;
						newShip.EquipItem(0, (ItemDesc)equipLaser2.Clone());
						newShip.EquipItem(1, (ItemDesc)equipLaser2.Clone());
					}
					if (stage > 1)
					{
						((Ship)(Player.Current.ControlObject)).HP+=0.5f;
						if (((Ship)(Player.Current.ControlObject)).HP>1.0f){
							((Ship)(Player.Current.ControlObject)).HP=1.0f;
						}
						for (int i = 0; i < stage; i++)
						{
							Ship newShip = Ship.Create(
								"ShipBP_HumanFighter", 
								"Fraction_Human",
								Player.Current.ControlObject.Pos.x + SteApp.Current.Rnd.Next(-1500, 1500)+5000.0f, 
								Player.Current.ControlObject.Pos.y + SteApp.Current.Rnd.Next(-1500, 1500)+5000.0f);
							newShip.AICapabilities = AICaps.Fight;
							newShip.EquipItem(0, (ItemDesc)equipLaser.Clone());
							newShip.EquipItem(1, (ItemDesc)equipLaser.Clone());
							newShip.EquipItem(2, (ItemDesc)equipLaser.Clone());
						}
					}
				}
				yield return null;
			}
		}
	}
}